/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var bench = require( '@stdlib/bench' );
var round = require( '@stdlib/math/base/special/round' );
var randu = require( '@stdlib/random/base/randu' );
var isArray = require( '@stdlib/assert/is-array' );
var pkg = require( './../package.json' ).name;
var incrspace = require( './../lib' );


// MAIN //

bench( pkg, function benchmark( b ) {
	var start;
	var stop;
	var i;
	var v;

	b.tic();
	for ( i = 0; i < b.iterations; i++ ) {
		start = round( randu()*100.0 );
		stop = start + 100;
		v = incrspace( start, stop );
		if ( typeof v !== 'object' ) {
			b.fail( 'should return an array' );
		}
	}
	b.toc();
	if ( !isArray( v ) ) {
		b.fail( 'should return an array' );
	}
	b.pass( 'benchmark finished' );
	b.end();
});

bench( pkg+':incr=10', function benchmark( b ) {
	var start;
	var incr;
	var stop;
	var i;
	var v;

	incr = 10;
	b.tic();
	for ( i = 0; i < b.iterations; i++ ) {
		start = round( randu()*100.0 );
		stop = start + (100*incr);
		v = incrspace( start, stop, incr );
		if ( typeof v !== 'object' ) {
			b.fail( 'should return an array' );
		}
	}
	b.toc();
	if ( !isArray( v ) ) {
		b.fail( 'should return an array' );
	}
	b.pass( 'benchmark finished' );
	b.end();
});
