/**
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var tape = require( 'tape' );
var detectClassSupport = require( './../../has-class-support' );
var isClass = require( './../lib' );


// VARIABLES //

var hasClassSupport = detectClassSupport();


// TESTS //

tape( 'main export is a function', function test( t ) {
	t.ok( true, __filename );
	t.strictEqual( typeof isClass, 'function', 'main export is a function' );
	t.end();
});

tape( 'the function returns `false` if not provided an ES2015 class', function test( t ) {
	var values;
	var i;

	values = [
		'5',
		5,
		NaN,
		null,
		void 0,
		true,
		[],
		{},
		function Person() {},
		new String( 'beep' ) // eslint-disable-line no-new-wrappers
	];

	for ( i = 0; i < values.length; i++ ) {
		t.strictEqual( isClass( values[i] ), false, 'returns false for when provided ' + values[i] );
	}
	t.end();
});

// Run positive tests if environment supports class...

if ( hasClassSupport ) {
	require( './es2015-class' ); // eslint-disable-line stdlib/no-unassigned-require
}
