/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var isArray = require( '@stdlib/assert/is-array' );
var array2buffer = require( './../../from-array' );


// MAIN //

/**
* Revives a JSON-serialized `Buffer`.
*
* @param {string} key - key
* @param {*} value - value
* @returns {(*|Buffer)} value or Buffer
*
* @example
* var parseJSON = require( '@stdlib/utils/parse-json' );
*
* var str = '{"type":"Buffer","data":[5,3]}';
*
* var buf = parseJSON( str, reviver );
* // returns <Buffer>[ 5, 3 ]
*/
function reviver( key, value ) {
	if (
		value &&
		value.type === 'Buffer' &&
		isArray( value.data )
	) {
		return array2buffer( value.data );
	}
	return value;
}


// EXPORTS //

module.exports = reviver;
