/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var tape = require( 'tape' );
var isStringArray = require( '@stdlib/assert/is-string-array' ).primitives;
var months = require( './../lib/browser.js' );


// TESTS //

tape( 'main export is a function', function test( t ) {
	t.ok( true, __filename );
	t.equal( typeof months, 'function', 'main export is a function' );
	t.end();
});

tape( 'the function returns an array of string primitives', function test( t ) {
	var list = months();
	t.equal( isStringArray( list ), true, 'returns an array of string primitives' );
	t.equal( list.length, 12, 'has length of 12' );
	t.end();
});

tape( 'the function returns a copy', function test( t ) {
	var l1;
	var l2;

	l1 = months();
	l2 = months();

	t.notEqual( l1, l2, 'different references' );

	l1[ 5 ] = 'beep';

	t.equal( l1[ 5 ], 'beep', 'expected element' );
	t.notEqual( l1[ 5 ], l2[ 5 ], 'no shared state' );
	t.equal( l2[ 5 ], 'June', 'expected element' );

	t.end();
});
