/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var isnan = require( './../../../../base/assert/is-nan' );


// MAIN //

/**
* Returns the positive difference between `x` and `y` if `x > y`; otherwise, returns `0`.
*
* @param {number} x - first number
* @param {number} y - second number
* @returns {number} positive difference
*
* @example
* var v = pdiff( 5.9, 3.14 );
* // returns 2.76
*
* @example
* var v = pdiff( 3.14, 4.2 );
* // returns 0.0
*
* @example
* var v = pdiff( 3.14, NaN );
* // returns NaN
*
* @example
* var v = pdiff( -0.0, +0.0 );
* // returns +0.0
*/
function pdiff( x, y ) {
	if ( isnan( x ) || isnan( y ) ) {
		return NaN;
	}
	if ( x > y ) {
		return x - y;
	}
	return 0.0;
}


// EXPORTS //

module.exports = pdiff;
