/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/*
* When adding modules to the namespace, ensure that they are added in alphabetical order according to module name.
*/

// MODULES //

var setReadOnly = require( '@stdlib/utils/define-read-only-property' );


// MAIN //

/**
* Top-level namespace.
*
* @namespace ns
*/
var ns = {};

/**
* @name fromBinaryStringUint32
* @memberof ns
* @readonly
* @type {Function}
* @see {@link module:@stdlib/number/uint32/base/from-binary-string}
*/
setReadOnly( ns, 'fromBinaryStringUint32', require( './../../../uint32/base/from-binary-string' ) );

/**
* @name rotl32
* @memberof ns
* @readonly
* @type {Function}
* @see {@link module:@stdlib/number/uint32/base/rotl}
*/
setReadOnly( ns, 'rotl32', require( './../../../uint32/base/rotl' ) );

/**
* @name rotr32
* @memberof ns
* @readonly
* @type {Function}
* @see {@link module:@stdlib/number/uint32/base/rotr}
*/
setReadOnly( ns, 'rotr32', require( './../../../uint32/base/rotr' ) );

/**
* @name toBinaryStringUint32
* @memberof ns
* @readonly
* @type {Function}
* @see {@link module:@stdlib/number/uint32/base/to-binary-string}
*/
setReadOnly( ns, 'toBinaryStringUint32', require( './../../../uint32/base/to-binary-string' ) );

/**
* @name uint32ToInt32
* @memberof ns
* @readonly
* @type {Function}
* @see {@link module:@stdlib/number/uint32/base/to-int32}
*/
setReadOnly( ns, 'uint32ToInt32', require( './../../../uint32/base/to-int32' ) );


// EXPORTS //

module.exports = ns;
